@@ -1,9 +1,5 @@
 from tkinter import *
 from playsound import playsound
-from socket import *
-class ServerClient:
-	def __init__(self,server):
-		self.server = server
 class Scene:
 	def up(e):
 		display.move(spr,0,-20)
